#!/bin/sh
#
# source: http://www.galago-project.org/files/releases/source/notify-python/notify-python-0.1.1.tar.bz2
#
# maintainer: gmg (g.monpontet@gmail.com)
#

#------------------ Set Some Variables

soft='notify-python'
softversion='0.1.1'
packageversion='72.1'

arch='i486'
cpu='i686'

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.bz2"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

rm -rf $src
tar -xvjf $srcpkg
rm -f $dest.tgz
rm -rf $dest

#------------------ Set correct permissions

cd $src
cat $buildir/notify-python-0.1.1-fix-GTK-symbols.patch | patch -p1 --verbose
cat $buildir/libnotify0.7patch | patch -p1 --verbose
chown -R root:root .
find . \
 \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
 -exec chmod 755 {} \; -o \
 \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
 -exec chmod 644 {} \;

#------------------ Start Configure

export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

./configure \
  --prefix=/usr

touch src/pynotify.override

make
make install DESTDIR=$dest

find $dest | xargs file | grep -e "shared object" -e "executable" | grep ELF \
  | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  
#------------------ Prepare the documentation

mkdir -p $dest/usr/doc/$soft-$softversion
cp -a AUTHORS ChangeLog COPYING NEWS $dest/usr/doc/$soft-$softversion

#------------------ Make the slack-desc files

mkdir -p $dest/install
cat << EODESC > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

             |-----handy-ruler-------------------------------------------------------|
notify-python: notify-python (Python bindings for libnotify)
notify-python:
notify-python: The notify-python package contains bindings to use libnotify with
notify-python: Python programs.
notify-python:
notify-python: Homepage for notify-python:  http://www.galago-project.org/
notify-python:
notify-python:
notify-python:
notify-python:
notify-python:
EODESC

mkdir -p $dest/usr/src/$soft-$softversion
cp -a $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

#------------------- Make the packages and the md5sum

cd $dest
makepkg -l y -c n $dest.txz

cd $buildir
md5sum $package.txz > $package.md5